/**
 * Created by Samuel Gratzl on 21.11.2016.
 */
import { getAPIJSON } from 'phovea_core/src/ajax';
import { offline } from 'phovea_core/src';
import i18n from 'phovea_core/src/i18n';
var BuildInfo = /** @class */ (function () {
    function BuildInfo(client, server) {
        this.client = client;
        this.server = server;
    }
    BuildInfo.prototype.toString = function () {
        return 'BuildInfo';
    };
    BuildInfo.prototype.buildBuildInfo = function () {
        var build = this.client;
        return "<table class=\"table table-bordered table-condensed\">\n            <tbody>\n              <tr><th>" + i18n.t('phovea:ui.application') + "</th><td>" + build.name + "</td></tr>\n              <tr><th>" + i18n.t('phovea:ui.version') + "</th><td>" + build.version + "</td></tr>\n              " + (this.server ? "<tr><th>Server</th><td>" + this.server.version + "</td></tr>" : '') + "\n              <tr><th>" + i18n.t('phovea:ui.url') + "</th><td><code>" + location.pathname + location.hash + "</code></td></tr>\n              <tr><th>" + i18n.t('phovea:ui.userAgent') + "</th><td>" + navigator.userAgent + "</td></tr>\n              <tr><th>" + i18n.t('phovea:ui.github') + "</th><td><a href=\"" + build.resolved.replace(/(\.git|\/commit\/).*/, '/issues/new') + "\" target=\"_blank\">" + i18n.t('phovea:ui.submitIssue') + "</a></td></tr>\n            </tbody>\n            </table>";
    };
    BuildInfo.prototype.buildIssuesContent = function () {
        // don't use location.href, since I don't wanna expose server names
        return "\n    " + i18n.t('phovea:ui.issueHeader') + "\n    " + i18n.t('phovea:ui.separator') + "\n    " + i18n.t('phovea:ui.applicationRow', { name: this.client.name }) + "\n    " + i18n.t('phovea:ui.versionRow', { version: this.client.version, resolved: this.client.resolved }) + (this.server ? i18n.t('phovea:ui.serverRow', { version: this.server.version, resolved: this.server.resolved }) : '') + "\n    " + i18n.t('phovea:ui.urlRow', { pathname: location.pathname, hash: location.hash }) + "\n    " + i18n.t('phovea:ui.userAgentRow', { userAgent: navigator.userAgent }) + "\n    " + i18n.t('phovea:ui.platformRow', { platform: navigator.platform }) + "\n    " + i18n.t('phovea:ui.screenSizeRow', { width: screen.width, height: screen.height }) + "\n    " + i18n.t('phovea:ui.windowSizeRow', { innerWidth: window.innerWidth, innerHeight: window.innerHeight }) + "\n\n~~~json\n" + JSON.stringify(this.client, null, ' ') + "\n" + (this.server ? "\n" + JSON.stringify(this.server, null, ' ') + "\n" : '') + "~~~";
    };
    BuildInfo.prototype.toHTML = function () {
        return "\n      <h4>" + i18n.t('phovea:ui.buildInfo') + "</h4>\n      " + this.buildBuildInfo() + "\n      <h4>" + i18n.t('phovea:ui.buildDetails') + "</h4>\n      <textarea readonly=\"readonly\">" + this.buildIssuesContent() + "</textarea>\n    ";
    };
    return BuildInfo;
}());
export { BuildInfo };
export default function build() {
    var buildInfos = Promise.all([
        self.fetch('./buildInfo.json').then(function (response) { return response.json(); }),
        offline ? null : getAPIJSON('/buildInfo.json')
    ]);
    return buildInfos.then(function (args) { return new BuildInfo(args[0], args[1]); });
}
//# sourceMappingURL=buildInfo.js.map