import { __extends } from "tslib";
import { AParentLayoutContainer } from './AParentLayoutContainer';
import { LayoutContainerEvents } from '../interfaces';
import TabbingLayoutContainer from './TabbingLayoutContainer';
var RootLayoutContainer = /** @class */ (function (_super) {
    __extends(RootLayoutContainer, _super);
    function RootLayoutContainer(document, build, restorer) {
        var _this = _super.call(this, document, {
            name: '',
            fixed: true
        }) || this;
        _this.build = build;
        _this.restorer = restorer;
        _this.minChildCount = 0;
        _this.type = 'root';
        _this.viewDump = null;
        _this.node.dataset.layout = 'root';
        _this.visible = true;
        _this.on(LayoutContainerEvents.EVENT_MAXIMIZE, function (_evt, view) {
            var section = _this.node.ownerDocument.createElement('section');
            section.classList.add('maximized-view');
            _this.viewDump = {
                parent: {
                    viewParent: view.node.parentElement,
                    headerParent: view.header.parentElement
                },
                sibling: {
                    viewSibling: view.node.nextElementSibling,
                    headerSibling: view.header.nextElementSibling
                }
            };
            section.appendChild(view.header);
            section.appendChild(view.node);
            _this.node.insertAdjacentElement('afterbegin', section);
            view.resized();
        });
        _this.on(LayoutContainerEvents.EVENT_RESTORE_SIZE, function (_evt, view) {
            if (!_this.viewDump) {
                return;
            }
            _this.viewDump.parent.viewParent.insertBefore(view.node, _this.viewDump.sibling.viewSibling);
            _this.viewDump.parent.headerParent.insertBefore(view.header, _this.viewDump.sibling.headerSibling);
            _this.viewDump = null;
            _this.node.querySelector('.maximized-view').remove();
            view.resized();
        });
        return _this;
    }
    Object.defineProperty(RootLayoutContainer.prototype, "root", {
        get: function () {
            return this._children[0];
        },
        set: function (root) {
            if (this._children.length > 0) {
                this.replace(this.root, root);
            }
            else {
                this.push(root);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RootLayoutContainer.prototype, "minSize", {
        get: function () {
            return this._children[0].minSize;
        },
        enumerable: true,
        configurable: true
    });
    RootLayoutContainer.prototype.addedChild = function (child, index) {
        _super.prototype.addedChild.call(this, child, index);
        if (child instanceof TabbingLayoutContainer) {
            //need the header
            this.node.appendChild(child.header);
        }
        this.node.appendChild(child.node);
        child.visible = this.visible;
    };
    RootLayoutContainer.prototype.place = function (child, reference, area) {
        return this.push(child);
    };
    RootLayoutContainer.prototype.takeDownChild = function (child) {
        if (child instanceof TabbingLayoutContainer) {
            this.node.removeChild(child.header);
        }
        this.node.removeChild(child.node);
        _super.prototype.takeDownChild.call(this, child);
    };
    RootLayoutContainer.prototype.restore = function (dump, restoreView) {
        var _this = this;
        console.assert(dump.type === 'root');
        this.clear();
        var children = (dump.children || []).map(function (dump) { return _this.restorer(dump, restoreView); });
        if (children.length === 0) {
            return;
        }
        this.root = children[0];
        children.slice(1).forEach(function (c) { return _this.push(c); });
    };
    RootLayoutContainer.prototype.persist = function () {
        return Object.assign(_super.prototype.persist.call(this), {
            type: 'root'
        });
    };
    RootLayoutContainer.restore = function (dump, doc, build, restorer, restoreView) {
        var r = new RootLayoutContainer(doc, function (layout) { return build(r, layout); }, restorer);
        r.restore(dump, restoreView);
        return r;
    };
    return RootLayoutContainer;
}(AParentLayoutContainer));
export default RootLayoutContainer;
//# sourceMappingURL=RootLayoutContainer.js.map