import { __extends } from "tslib";
import { ALayoutContainer, withChanged } from './ALayoutContainer';
import { dropViews } from './dropper';
import { LayoutContainerEvents } from '../';
var HTMLView = /** @class */ (function () {
    function HTMLView(html, doc) {
        this.minSize = [0, 0];
        this.visible = true;
        //HTML
        this.node = doc.createElement('div');
        this.node.innerHTML = html;
    }
    HTMLView.prototype.destroy = function () {
        //nothing to do
    };
    HTMLView.prototype.resized = function () {
        //nothing to do
    };
    HTMLView.prototype.dumpReference = function () {
        return -1;
    };
    return HTMLView;
}());
export { HTMLView };
var NodeView = /** @class */ (function () {
    function NodeView(node) {
        this.node = node;
        this.minSize = [0, 0];
        this.visible = true;
    }
    NodeView.prototype.destroy = function () {
        //nothing to do
    };
    NodeView.prototype.resized = function () {
        //nothing to do
    };
    NodeView.prototype.dumpReference = function () {
        return -1;
    };
    return NodeView;
}());
export { NodeView };
var ViewLayoutContainer = /** @class */ (function (_super) {
    __extends(ViewLayoutContainer, _super);
    function ViewLayoutContainer(view, options) {
        var _this = _super.call(this, view.node.ownerDocument, options) || this;
        _this.view = view;
        _this.type = 'view';
        _this.node = view.node.ownerDocument.createElement('article');
        _this.node.dataset.layout = 'view';
        _this.node.appendChild(view.node);
        _this.header.insertAdjacentHTML('beforeend', "<button type=\"button\" title=\"Expand view\" class=\"size-toggle\" aria-label=\"Toggle View Size\"><span><i class=\"fa fa-expand\"></i></span></button>");
        var min = _this.minSize;
        if (min[0] > 0) {
            view.node.style.minWidth = min[0] + "px";
        }
        if (min[1] > 0) {
            view.node.style.minHeight = min[1] + "px";
        }
        if (!_this.options.fixedLayout) {
            dropViews(_this.node, _this);
        }
        _this.updateTitle();
        _this.header.querySelector('.size-toggle').addEventListener('click', function () { return _this.toggleMaximizedView(); });
        _this.header.addEventListener('dblclick', function () { return _this.toggleMaximizedView(); });
        return _this;
    }
    ViewLayoutContainer.prototype.defaultOptions = function () {
        return Object.assign(_super.prototype.defaultOptions.call(this), {
            hideHeader: false
        });
    };
    Object.defineProperty(ViewLayoutContainer.prototype, "hideAbleHeader", {
        get: function () {
            return this.options.hideHeader;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ViewLayoutContainer.prototype, "visible", {
        get: function () {
            return this.view.visible;
        },
        set: function (visible) {
            this.fire(withChanged(LayoutContainerEvents.EVENT_VISIBILITY_CHANGED), this.view.visible, this.view.visible = visible);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ViewLayoutContainer.prototype, "minSize", {
        get: function () {
            return this.view.minSize ? this.view.minSize : [0, 0];
        },
        enumerable: true,
        configurable: true
    });
    ViewLayoutContainer.prototype.resized = function () {
        if (this.view.resized) {
            this.view.resized();
        }
    };
    ViewLayoutContainer.prototype.destroy = function () {
        _super.prototype.destroy.call(this);
        if (this.parent) {
            this.parent.remove(this);
        }
        this.view.destroy();
    };
    ViewLayoutContainer.prototype.persist = function () {
        var r = Object.assign(_super.prototype.persist.call(this), {
            type: 'view'
        });
        if (this.view instanceof HTMLView) {
            r.html = this.view.node.innerHTML;
        }
        else {
            r.view = this.view.dumpReference();
        }
        return r;
    };
    ViewLayoutContainer.restore = function (dump, restoreView, doc) {
        var view = dump.html ? new HTMLView(dump.html, doc) : restoreView(dump.view);
        return new ViewLayoutContainer(view, ALayoutContainer.restoreOptions(dump));
    };
    ViewLayoutContainer.derive = function (view) {
        return new ViewLayoutContainer(view, ALayoutContainer.deriveOptions(view.node));
    };
    return ViewLayoutContainer;
}(ALayoutContainer));
export default ViewLayoutContainer;
//# sourceMappingURL=ViewLayoutContainer.js.map